@@ -6,19 +6,15 @@
 #' `all(x[!is.na(x)] >= value)`
 #'
 #' @inheritParams params
-#' @return
-#' The `chk_` function throws an informative error if the test fails.
-#'
-#' The `vld_` function returns a flag indicating whether the test was met.
+#' @inherit params return
 #'
 #' @family chk_ranges
-#' @export
 #'
 #' @examples
-#'
 #' # chk_gte
 #' chk_gte(0)
 #' try(chk_gte(-0.1))
+#' @export
 chk_gte <- function(x, value = 0, x_name = NULL) {
   if (vld_gte(x, value)) {
     return(invisible())
@@ -27,7 +23,8 @@ chk_gte <- function(x, value = 0, x_name = NULL) {
   if (length(x) == 1L) {
     abort_chk(
       x_name, " must be greater than or equal to ", cc(value),
-      ", not ", cc(x), x = x, value = value
+      ", not ", cc(x),
+      x = x, value = value
     )
   }
   abort_chk(x_name, " must have values greater than or equal to ", cc(value), x = x, value = value)
@@ -35,14 +32,12 @@ chk_gte <- function(x, value = 0, x_name = NULL) {
 
 #' @describeIn chk_gte Validate Greater Than or Equal To
 #'
-#' @export
-#'
 #' @examples
-#'
 #' # vld_gte
 #' vld_gte(numeric(0))
 #' vld_gte(0)
 #' vld_gte(-0.1)
 #' vld_gte(c(0.1, 0.2, NA))
 #' vld_gte(c(0.1, 0.2, NA), value = 1)
+#' @export
 vld_gte <- function(x, value = 0) all(x[!is.na(x)] >= value)
