@@ -4,7 +4,7 @@ from types import MappingProxyType
 import click
 
 import chk.modules.http.main as http_executor
-import chk.modules.test_spec.main as test_spec_executor
+import chk.modules.testcase.main as testcase_executor
 
 
 # run command
@@ -24,20 +24,22 @@ def execute_http(file, result):
 
 
 # run command
-@click.command('test-spec')
+@click.command('testcase')
 @click.argument('file', nargs=-1)
-def execute_test_spec(file):
+def execute_testcase(file):
     """Command to run HTTP request config file.\r\n
-    FILE: Any .chk file, that has 'version: default.test-spec.*' string in it."""
-    test_spec_executor.execute()
+    FILE: Any .chk file, that has 'version: default.testcase.*' string in it."""
+
+    file = list(file).pop(0)
+    testcase_executor.execute(file)
 
 
 # root command
 @click.group('chk')
 def execute_root():
-    """v0.3.4 | supported version strings: 0.7.2"""
+    """v0.4.0 | supported version strings: 0.7.2"""
     pass
 
 
 execute_root.add_command(execute_http)  # add `http` as sub-command
-# execute_root.add_command(execute_test_spec)  # add `http` as sub-command
+execute_root.add_command(execute_testcase)  # add `testcase` as sub-command
