@@ -14,6 +14,11 @@ messages = dict(
         V0006='File exception: Validation failed',
         V0007='System exception: Not a Callable',
         V0008='System exception: Wrong spec class',
+
+        # testcase errors
+        V0020='None or many request found',
+        V0021='Pass data on same context',
+        V0029='File linking not supported',
     )
 )
 
