@@ -3,6 +3,8 @@ Lexical analysis functionalities
 """
 import re
 
+from chk.console.helper import data_get
+
 
 class StringLexicalAnalyzer:
     """Lexical analyzer for strings"""
@@ -12,12 +14,13 @@ class StringLexicalAnalyzer:
         if type(container) is not str: raise TypeError
         if len(replace_with) == 0: return container
 
-        line_split = re.split("{|}", container)
-        line_strip = [item.strip() for item in line_split if item]
+        line_split = re.split(r'({\s*\$\w+\s*})', container)
+        line_strip = [''.join(item.split()) for item in line_split if item]
 
         for i, item in enumerate(line_strip):
+            item = item.strip('{}')
             if item.startswith('$'):
-                value = replace_with.get(item.lstrip('$'), None)
+                value = data_get(replace_with, item.lstrip('$'), None)
                 line_strip[i] = str(value) if value else '{' + item + '}'
 
         return ''.join(line_strip)
